@@ -1,21 +1,24 @@
 /*
- * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2003 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -31,6 +34,10 @@
  * adam.w    27 Mar 01 - Made into KEXT
  * adam.w    30 Jan 02 - Fixed local mode and use new CPU-SW versioning 102.0.1
  *                       which is 1.0.2d1
+ * adam.w    6 June 03 - Obsolete this KEXT.  In extreme cases this KEXT can 
+ * 		         still work if Info.plist entry for "ADB-KEXT-Obsolete" 
+ *			 is changed to 0.  For now, all this KEXT does is set the 
+ *			 ADB monitor to "local" buttons mode and then exits.
  */
 
 #include <IOKit/assert.h>
@@ -256,7 +263,19 @@ bool AppleADBDisplay::start( IOService * nub )
 {
     IOReturn	err;
     UInt16	data, deviceType;
+    OSNumber	*datan;
 
+    datan = OSDynamicCast( OSNumber, getProperty( "ADB-KEXT-Obsolete" ));
+    if (datan)
+    {
+	if (datan->unsigned32BitValue())
+	{
+	    adbDevice = (IOADBDevice *) nub;
+	    setLocalMode();
+	    return false;  //Don't need to waste kernel memory
+	}
+    }
+    
     if( !super::start( nub))
         return false;
 
